% SBS() - Performes one step of the sequential backwards step. Each
%         feature is left out in turn and their classification accuracy is 
%         calculated. The subset of features of length k-1 with the
%         greatest classification rate are returned.
%
% Usage:
%   >> [SBSfeatures SBSOCR] = SBS(features, FV, k, labels, val,part)
%
% Inputs: 
%   features - Current feature set of length k.
%   FV       - Nxl array of feature vectors where N is number of feature
%              vectors and l is number of features.
%   k        - current number of chosen features.
%   labels   - N length array class labels for feature vectors, 2 class 
%              only, 1's for class 1 and 2's for class 2
%   val      - integer representing validation type
%               1 - test-set
%               2 - kfolds
%               3 - leave-one-out
%   part     - randomly generated indices from 1 to N
%
% Outputs:
%   SBSfeatures - Subset of features of length k-1 that gives the best
%                 classification accuracy.
%   SBSOCR      - Classification accuracy of chosen feature set.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: eegplugin_SFT() stepwiseRegression()

function [SBSfeatures SBSOCR] = SBS(features, FV, k, labels, val,part)

j=1;
SBSOCR=0;
SBSfeatures=[];
while j<=k && k>1

    testSet=features(k,1:k);
    testSet(j)=[];
    j=j+1;

    if SBSOCR < LeaveOneOut(FV(:,testSet),labels)
        if val==1
            SBSOCR=validation(FV(:,testSet),labels);
        elseif val==2
            SBSOCR=kfolds(FV(:,testSet),labels,part);
        elseif val==3
            SBSOCR=LeaveOneOut(FV(:,testSet),labels);
        end
        SBSfeatures=testSet;
    end        
end