% SFS() - Performes one step of the sequential forward step. Each available
%         feature is added to the chosen feature set and the feature that
%         gives the best classification accuracy is added to the chosen
%         feature set and k is incremented.
%
% Usage:
%   >> [features2 OCR] = SFS(features, featureIndex, FV, labels, k,val,part)
%
% Inputs: 
%   features     - Current feature set of length k.
%   featureIndex - array of 1:total number of features
%   FV           - Nxl array of feature vectors where N is number of 
%                  feature vectors and l is number of features.
%   labels       - N length array class labels for feature vectors, 2 class 
%                  only, 1's for class 1 and 2's for class 2
%   k            - current number of chosen features.
%   val          - integer representing validation type
%                   1 - test-set
%                   2 - kfolds
%                   3 - leave-one-out
%   part         - randomly generated indices from 1 to N
%
% Outputs:
%   features2 - Set of chosen features.
%   OCR       - Classification accuracy of chosen feature set.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: eegplugin_SFT() stepwiseRegression()

function [features2 OCR] = SFS(features, featureIndex, FV, labels, k,val,part)

%feature index goes from 1 to the number of features
currentFeatureIndex=featureIndex;
%removes all of the features already chosen for the set
if features(1,1) ~= 0
    currentFeatureIndex(features(k,1:k))=[];
end
%finds the OCR for the current feature set plus one additional feature
%does this for each feature not already in the set
if features(1,1) ~= 0
    FeatureOCRs=zeros(length(currentFeatureIndex),1);
    for i=1:length(currentFeatureIndex)
        if val==1
            FeatureOCRs(currentFeatureIndex(i))=validation(FV(:,[features(k,1:k) currentFeatureIndex(i)]),labels);
        elseif val==2
            FeatureOCRs(currentFeatureIndex(i))=kfolds(FV(:,[features(k,1:k) currentFeatureIndex(i)]),labels,part);
        elseif val==3
            FeatureOCRs(currentFeatureIndex(i))=LeaveOneOut(FV(:,[features(k,1:k) currentFeatureIndex(i)]),labels);
        end
    end
else
    FeatureOCRs=zeros(length(currentFeatureIndex),1);
    for i=1:length(currentFeatureIndex)        
        if val==1
            FeatureOCRs(currentFeatureIndex(i))=validation(FV(:,currentFeatureIndex(i)),labels);
        elseif val==2
            FeatureOCRs(currentFeatureIndex(i))=kfolds(FV(:,currentFeatureIndex(i)),labels,part);
        elseif val==3
            FeatureOCRs(currentFeatureIndex(i))=LeaveOneOut(FV(:,currentFeatureIndex(i)),labels);
        end
    end
end
%Adds the best feature not already in the set to the set
% FeatureOCRs
[OCR features2]=max(FeatureOCRs);
