% eegplugin_FST() - The Feature Selection Toolbox (FST) is a plug-in to the
%                   EEGLAB toolbox. FST allows the creation of features and
%                   the selection of the near optimal subset of features.
%
% Usage:
%   >> vers = eegplugin_FST(fig, trystrs, catchstrs)
%
% Inputs: 
%   fig        - [integer]  EEGLAB figure
%   trystrs    - [struct] "try" strings for menu callbacks.
%   catchstrs  - [struct] "catch" strings for menu callbacks. 
%
% Outputs:
%   vers       - Current version of plugin.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: 

function vers = eegplugin_FST(fig, trystrs, catchstrs)

vers = 'Featue Selection Toolbox 1.3';

global FV
FV.data=[];

% add plugin folder to path
% -----------------------
if exist('SFS.m','file')
    p = which('eegplugin_FST');
    p = p(1:findstr(p,'stepwiseRegression.m')-1);
    addpath(p);    
end;

% find tools menu
% ---------------------
menu = findobj(fig, 'tag', 'tools');

submenu = uimenu(menu,'Label', 'FST');

% menu callbacks
% --------------
classLabel_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_classLabel(ALLEEG);' catchstrs.add_to_hist ];
apm_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_APM(ALLEEG);' catchstrs.new_and_hist ];
coh_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_coherence(ALLEEG);' catchstrs.new_and_hist ];
corr_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_corr(ALLEEG);' catchstrs.new_and_hist ];
phase_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_phaseSynchrony(ALLEEG);' catchstrs.new_and_hist ];
wavelet_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_wavelet(ALLEEG);' catchstrs.new_and_hist ];
%USER DEFINED CALLBACKS
%------------------------------------

%------------------------------------
SFFS_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_stepwiseRegression(ALLEEG);' catchstrs.new_and_hist ];
FVsave_cback = [ trystrs.no_check '[ALLEEG LASTCOM] = pop_features2excel(ALLEEG);' catchstrs.new_and_hist ];


% create menus if necessary
% -------------------------
uimenu(submenu,'Label','Class Label Files', 'CallBack', classLabel_cback);
submenuFG = uimenu(submenu,'Label','Feature Generation');
uimenu( submenuFG, 'Label', 'Average Power Method', 'CallBack', apm_cback);
uimenu( submenuFG, 'Label', 'Coherence Method', 'CallBack', coh_cback);
uimenu( submenuFG, 'Label', 'Correlation Coefficient', 'CallBack', corr_cback);
uimenu( submenuFG, 'Label', 'Phase Synchrony', 'CallBack', phase_cback);
uimenu( submenuFG, 'Label', 'CWT', 'CallBack', wavelet_cback);
%USER ADDED FEATURE GENERATION METHODS
%------------------------------------

%------------------------------------
uimenu(submenu,'Label','Feature Selection','CallBack',SFFS_cback);
uimenu(submenu,'Label','Save Features to Excel File','CallBack',FVsave_cback);

