% kfolds() - Classifies k partitions of feature vectors from a classifier
%            trained from the remaining partitions. The average result is
%            returned as the overall classification rate (OCR).
%
% Usage:
%   >> OCR = kfolds(data, labels, part)
%
% Inputs: 
%   data   - Nxl array of feature vectors where N is number of feature
%            vectors and l is number of features.
%   labels - N length array class labels for feature vectors, 2 class only, 
%            1's for class 1 and 2's for class 2
%   part   - N length array of randomly generated indicies of 1 to N.
%
% Outputs:
%   OCR    - Average classification rate of the partitions.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: eegplugin_FST() classify()

function OCR = kfolds(data, labels, part)

global numobj
numobj=numobj+1;

labelsize=size(labels);
if labelsize(1) == 1
    labels=labels';
end
OCRsingle=zeros(length(part),1);
trainpart=[];
for i=1:length(part)
    testData=data(part{i},:);
    testLabels=labels(part{i});
    
    for k=1:length(part)
        if k~=i
            trainpart=[trainpart part{k}];
        end
    end
    trainData=data(trainpart,:);
    trainLabels=labels(trainpart);
    try
        testClass = classify(testData,trainData,trainLabels);
    catch ME
        testClass=0;
    end

    OCRsingle(i)=sum(testClass==testLabels)/length(testClass);
end
OCR=mean(OCRsingle);