% pop_classLabel() - Labels each EEG set loaded with a class value.
%
% Usage:
%   >> [ALLEEG com] = pop_classLabel(ALLEEG, classLabels)
%
% Inputs: 
%   ALLEEG                - Input struct containing all loaded EEG sets.
%   classLabels(optional) - Array containing one integer value for each EEG
%                           set currently loaded.
%
% Outputs:
%   ALLEEG - Output struct containing all loaded EEG sets.
%   com    - Command tag.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: eegplugin_FST() 

function [ALLEEG com] = pop_classLabel(ALLEEG, classLabels)

com='';
uilist={};
numClasses=2;

%is input display needed?
%---------------------------
displayInput=0;
if nargin > 2
    if length(classLabels) ~= length(ALLEEG)
        displayInput = 1;
    end
end
if nargin < 2
    displayInput=1;
end
%request user input
%----------------------------
if displayInput
    %draw gui for entering number of classes
    %--------------------------------
    uigeom = 2;
    
    uilist{end+1} = { 'style' 'text'      'string'    'Number of Classes: '};
    uilist{end+1} = { 'style' 'edit'      'string'    num2str(numClasses)};
   
    guititle = 'Defining Classes';
    numClassesStr = inputgui( uigeom, uilist, 'pophelp(''pop_APM'')', guititle, [], 'normal');
    if isempty(numClassesStr)
        return;
    end
    numClasses=str2double(numClassesStr{1});
    %draw gui for data sets to classes
    %--------------------------------
    uilist=[];
    uigeom(1:numClasses) = 2;
    for i=1: numClasses
        class{i}=[num2str(1+(i-1)*floor(length(ALLEEG)/ numClasses)) ':' num2str(floor(length(ALLEEG)/ numClasses)*i)];
    end
    class{numClasses}=[num2str(1+(numClasses-1)*floor(length(ALLEEG)/ numClasses)) ':' num2str(floor(length(ALLEEG)/ numClasses)*numClasses+mod(length(ALLEEG),numClasses))];
    for i=1: numClasses
        uilist{end+1} = { 'style' 'text'      'string'    ['Data Sets in class ' num2str(i) ': ']};
        uilist{end+1} = { 'style' 'edit'      'string'    class{i}};
    end
    guititle = 'Defining Classes';
    class2 = inputgui( uigeom, uilist, 'pophelp(''pop_APM'')', guititle, [], 'normal');
    if isempty(class2)
        return;
    end
    classLabels=[];
    for i=1: numClasses
        temp=str2num(class2{i});
        for j=1:length(temp)
            classLabels(end+1)=i;
        end
    end
end

%check valid input
%-------------------------------
if isempty(classLabels) || length(classLabels) ~= length(ALLEEG)
    disp('(pop_classLabel) error: Invalid Class Labels'); return;
end

%add class information to each EEG structure
%--------------------------------------------
for i=1:length(ALLEEG)
    ALLEEG(i).class=classLabels(i);
end

com = sprintf( 'test');