% pop_features2excel() - Saves feature vectors to excel file specified by 
%                        'path'.
%
% Usage:
%   >> [ALLEEG com] = pop_features2excel(ALLEEG, path)
%
% Inputs: 
%   ALLEEG         - Input struct containing all loaded EEG sets.
%   path(optional) - File path to save features to.
%
% Outputs:
%   ALLEEG - Output struct containing all loaded EEG sets.
%   com    - Command tag.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: eegplugin_FST() xlswrite()

function [ALLEEG com] = pop_features2excel(ALLEEG, path)

global FV

com='';

if nargin < 1,
    help pop_SaveFeatures;
    return;
end

%make sure features are generated
%----------------------------------
if isempty(FV.data)
    disp('(pop_SFFS) error: No Feature Vectors'); return;
end

if nargin < 2
    [FileName,PathName] = uiputfile('*.xls','Select File to Save to');
    if FileName==0
        return;
    end
    path=[PathName FileName];
end

xlswrite(path,FV.data,1,'B2');

featureLabels={};
for i=1:size(FV.data,2)
    featureLabels{end+1}=[num2str(i) ' ' char(FV.Flabels(FV.featureNumbers(i)))];
end

xlswrite(path,featureLabels,1,'B1');

FVlabels={};
for i=1:length(ALLEEG)
    for j=1:size(ALLEEG(i).data,3)
        FVlabels{end+1}=['C' num2str(ALLEEG(i).class) 'F' num2str(i) 'E' num2str(j)];
    end
end

xlswrite(path,FVlabels',1,'A2');

if ~isempty(FV.OCR)
    OCR_Out{1}='OCR';
    OCR_Out{2}=num2str(FV.OCR*100);
    xlswrite(path,OCR_Out,2,'A1');
end

% com=['%s = pop_SaveFeatures( %s );', inputname(1), inputname(1)];