% validation() - test-set validation
%
% Usage:
%   >> OCR = validation(data, labels)
%
% Inputs: 
%   data   - Nxl array of feature vectors where N is number of feature
%            vectors and l is number of features.
%   labels - N length array class labels for feature vectors, 2 class only, 
%            1's for class 1 and 2's for class 2
%
% Outputs:
%   OCR    - Overall classification rate of the LDA classifier with the
%            feature vector inputs of data. OCR = correctly classified
%            feature vectors / total number of feature vectors.
%
% Note: 
%
% Author: Andy Kerr, Autumn's Dawn NICE Lab, 2010
%
% See also: eegplugin_FST() classify()

function OCR = validation(data, labels)

global numobj
numobj=numobj+1;

totalFV = size(data,1);
labelsize=size(labels);
if labelsize(1) == 1
    labels=labels';
end

testSize=ceil(.1*totalFV);
testData=data([1:testSize end-testSize+1:end],:);
testLabels=labels([1:testSize end-testSize+1:end]);
trainData=data(testSize+1:end-testSize,:);
trainLabels=labels(testSize+1:end-testSize);
try
    testClass = classify(testData,trainData,trainLabels);
catch ME
    testClass=0;
end

OCR=sum(testClass==testLabels)/size(testLabels,1);